DataLad |---| data management and distribution suite: Documentation
*******************************************************************

.. toctree::
   :maxdepth: 1

   gettingstarted
   changelog
   acknowledgements

Concepts and technologies
=========================

.. toctree::
   :maxdepth: 2

   background
   related
   basics
   usecases/index
   metadata
   customization
   glossary

Commands and API
================

.. toctree::
   :maxdepth: 2

   cmdline
   modref
   config

Automated data distributions
============================

.. toctree::
   :maxdepth: 2

   crawler/index

Extension modules
=================

- `Neuroimaging data and workflows <http://docs.datalad.org/projects/neuroimaging>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
